==> pyabaqus-1.0.3-py2.py3-none-any.whl: abaqus/Amplitude/SolutionDependentAmplitude.py <==
from abaqusConstants import *
from .Amplitude import Amplitude


class SolutionDependentAmplitude(Amplitude):
    """The SolutionDependentAmplitude object defines a solution-dependent amplitude for
    superplastic forming analysis. 
    The SolutionDependentAmplitude object is derived from the Amplitude object. 

    Access
    ------
        - import amplitude
        - mdb.models[name].amplitudes[name]
        - import odbAmplitude
        - session.odbs[name].amplitudes[name]

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------
        - AMPLITUDE

    """

    def __init__(self, name: str, initial: float = 1, minimum: float = 0, maximum: float = 1000,
                 timeSpan: SymbolicConstant = STEP):
        """This method creates a SolutionDependentAmplitude object.

        Path
        ----
            - mdb.models[name].SolutionDependentAmplitude
            - session.odbs[name].SolutionDependentAmplitude

        Parameters
        ----------
        name
            A String specifying the repository key. 
        initial
            A Float specifying the initial amplitude value. Possible values are those between 
            *minimum* and *maximum*. The default value is 1.0. 
        minimum
            A Float specifying the minimum amplitude value. Possible values are those smaller than 
            *maximum* and *initial*. The default value is 0.1. 
        maximum
            A Float specifying the maximum amplitude value. Possible values are those larger than 
            *minimum* and *initial*. The default value is 1000.0. 
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP 
            and TOTAL. The default value is STEP. 

        Returns
        -------
            A SolutionDependentAmplitude object. 

        Exceptions
        ----------
            InvalidNameError and RangeError. 
        """
        super().__init__()
        pass

    def setValues(self, initial: float = 1, minimum: float = 0, maximum: float = 1000,
                  timeSpan: SymbolicConstant = STEP):
        """This method modifies the SolutionDependentAmplitude object.

        Parameters
        ----------
        initial
            A Float specifying the initial amplitude value. Possible values are those between 
            *minimum* and *maximum*. The default value is 1.0. 
        minimum
            A Float specifying the minimum amplitude value. Possible values are those smaller than 
            *maximum* and *initial*. The default value is 0.1. 
        maximum
            A Float specifying the maximum amplitude value. Possible values are those larger than 
            *minimum* and *initial*. The default value is 1000.0. 
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP 
            and TOTAL. The default value is STEP. 

        Returns
        -------
            None. 

        Exceptions
        ----------
            RangeError. 
        """
        pass

==> pyabaqus-1.0.5-py2.py3-none-any.whl: abaqus/Amplitude/SolutionDependentAmplitude.py <==
from abaqusConstants import *
from .Amplitude import Amplitude


class SolutionDependentAmplitude(Amplitude):
    """The SolutionDependentAmplitude object defines a solution-dependent amplitude for
    superplastic forming analysis. 
    The SolutionDependentAmplitude object is derived from the Amplitude object. 

    Access
    ------
        - import amplitude
        - mdb.models[name].amplitudes[name]
        - import odbAmplitude
        - session.odbs[name].amplitudes[name]

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------
        - AMPLITUDE

    """

    def __init__(self, name: str, initial: float = 1, minimum: float = 0, maximum: float = 1000,
                 timeSpan: SymbolicConstant = STEP):
        """This method creates a SolutionDependentAmplitude object.

        Path
        ----
            - mdb.models[name].SolutionDependentAmplitude
            - session.odbs[name].SolutionDependentAmplitude

        Parameters
        ----------
        name
            A String specifying the repository key. 
        initial
            A Float specifying the initial amplitude value. Possible values are those between 
            *minimum* and *maximum*. The default value is 1.0. 
        minimum
            A Float specifying the minimum amplitude value. Possible values are those smaller than 
            *maximum* and *initial*. The default value is 0.1. 
        maximum
            A Float specifying the maximum amplitude value. Possible values are those larger than 
            *minimum* and *initial*. The default value is 1000.0. 
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP 
            and TOTAL. The default value is STEP. 

        Returns
        -------
            A SolutionDependentAmplitude object.  and RangeError. 
        """
        super().__init__()
        pass

    def setValues(self, initial: float = 1, minimum: float = 0, maximum: float = 1000,
                  timeSpan: SymbolicConstant = STEP):
        """This method modifies the SolutionDependentAmplitude object.

        Parameters
        ----------
        initial
            A Float specifying the initial amplitude value. Possible values are those between 
            *minimum* and *maximum*. The default value is 1.0. 
        minimum
            A Float specifying the minimum amplitude value. Possible values are those smaller than 
            *maximum* and *initial*. The default value is 0.1. 
        maximum
            A Float specifying the maximum amplitude value. Possible values are those larger than 
            *minimum* and *initial*. The default value is 1000.0. 
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP 
            and TOTAL. The default value is STEP.

        Exceptions
        ----------
            RangeError. 
        """
        pass
